@@ -4,6 +4,7 @@
 # Distributed under the terms of the Modified BSD License.
 
 import argparse
+import json
 import logging
 import os
 import sys
@@ -14,15 +15,17 @@ from ._version import __version__
 from .log import init_logging, set_nbdime_log_level
 from .gitfiles import is_gitref
 from .diffing.notebooks import set_notebook_diff_targets, set_notebook_diff_ignores
-from .config import get_defaults_for_argparse, entrypoint_configurables
+from .config import (
+    get_defaults_for_argparse, build_config, entrypoint_configurables,
+    Namespace
+)
 from .prettyprint import pretty_print_dict, PrettyPrintConfig
 
 
 class ConfigBackedParser(argparse.ArgumentParser):
 
-    def parse_args(self, args=None, namespace=None, entrypoint=None):
-        if entrypoint is None:
-            entrypoint = self.prog
+    def parse_known_args(self, args=None, namespace=None):
+        entrypoint = self.prog.split(' ')[0]
         try:
             defs = get_defaults_for_argparse(entrypoint)
             ignore = defs.pop('Ignore', None)
@@ -31,7 +34,7 @@ class ConfigBackedParser(argparse.ArgumentParser):
                 set_notebook_diff_ignores(ignore)
         except ValueError:
             pass
-        return super(ConfigBackedParser, self).parse_args(args=args, namespace=namespace)
+        return super(ConfigBackedParser, self).parse_known_args(args=args, namespace=namespace)
 
 
 class LogLevelAction(argparse.Action):
@@ -57,6 +60,27 @@ class SkipAction(argparse.Action):
         pass
 
 
+def modify_config_for_print(config):
+    output = {}
+    ns = None
+    for k, v in config.items():
+        if isinstance(v, dict):
+            output[k] = modify_config_for_print(v)
+            if not output[k]:
+                output[k] = '{}'
+        elif k in diff_exclusives and v is None:
+            if ns is None:
+                ns = Namespace(config)
+                for k in diff_exclusives:
+                    setattr(ns, k, config.get(k, None))
+                process_exclusive_ignorables(ns, diff_exclusives)
+            output[k] = '<unset, resolves to {0}>'.format(
+                json.dumps(getattr(ns, k, v)))
+        else:
+            output[k] = json.dumps(v)
+    return output
+
+
 class ConfigHelpAction(argparse.Action):
     def __init__(self, option_strings, dest, help=None):
         super(ConfigHelpAction, self).__init__(
@@ -64,9 +88,10 @@ class ConfigHelpAction(argparse.Action):
 
     def __call__(self, parser, namespace, values, option_string=None):
         header = entrypoint_configurables[parser.prog].__name__
+        config = build_config(parser.prog, True)
         pretty_print_dict(
             {
-                header: get_defaults_for_argparse(parser.prog),
+                header: modify_config_for_print(config),
             },
             config=PrettyPrintConfig(out=sys.stderr)
         )
