@@ -39,6 +39,8 @@ re_repr = re.compile(r"<[a-z0-9._]+ at 0x[a-f0-9]{8,16}>", re.IGNORECASE)
 
 re_pointer = re.compile(r"0x[a-f0-9]{8,16}", re.IGNORECASE)
 
+TEXT_MIMEDATA_MAX_COMPARE_LENGTH = 10000
+
 
 # List of mimes we can diff recursively
 _split_mimes = (
@@ -61,7 +63,7 @@ def _is_base64(test_string, min_len=64):
 
 
 @lru_cache(maxsize=1024, typed=False)
-def compare_text_approximate(x, y):
+def compare_text_approximate(x, y, maxlen=None):
     # Fast cutoff when one is empty
     if bool(x) != bool(y):
         return False
@@ -81,10 +83,10 @@ def compare_text_approximate(x, y):
     if nx < shortlen and ny < shortlen:
         return True
 
-    return compare_strings_approximate(x, y, threshold=0.7)
+    return compare_strings_approximate(x, y, threshold=0.7, maxlen=maxlen)
 
 
-def compare_text_strict(x, y):
+def compare_text_strict(x, y, maxlen=None):
     # TODO: Doesn't have to be 100% equal here?
     if isinstance(x, list):
         x = "".join(x)
@@ -92,7 +94,15 @@ def compare_text_strict(x, y):
         y = "".join(y)
     if len(x) == len(y) and x == y:
         return True
-    return compare_strings_approximate(x, y, threshold=0.95)
+    return compare_strings_approximate(x, y, threshold=0.95, maxlen=maxlen)
+
+
+def make_compare_text(maxlen, strict):
+    def compare_text(x, y):
+        if strict:
+            return compare_text_strict(x, y, maxlen=maxlen)
+        return compare_text_approximate(x, y, maxlen=maxlen)
+    return compare_text
 
 
 def compare_base64_strict(x, y):
@@ -136,12 +146,16 @@ def _compare_mimedata(mimetype, x, y, comp_text, comp_base64):
 
 def compare_mimedata_approximate(mimetype, x, y):
     return _compare_mimedata(
-        mimetype, x, y, compare_text_approximate, compare_base64_strict)
+        mimetype, x, y,
+        make_compare_text(maxlen=TEXT_MIMEDATA_MAX_COMPARE_LENGTH, strict=False),
+        compare_base64_strict)
 
 
 def compare_mimedata_strict(mimetype, x, y):
     return _compare_mimedata(
-        mimetype, x, y, compare_text_strict, compare_base64_strict)
+        mimetype, x, y,
+        make_compare_text(maxlen=TEXT_MIMEDATA_MAX_COMPARE_LENGTH, strict=True),
+        compare_base64_strict)
 
 
 def compare_mimebundle_approximate(x, y):
@@ -488,7 +502,7 @@ def diff_ignore_keys(inner_differ, ignore_keys):
     """Call inner_differ, but filter the resulting diff.
 
     Will ignore all direct diff values that has a key in
-    ignore_keys. I.e. this will not recurse into patch ops.abs
+    ignore_keys. I.e. this will not recurse into patch ops.
     """
     def ignored_diff(*args, **kwargs):
         d = inner_differ(*args, **kwargs)
@@ -554,6 +568,8 @@ def set_notebook_diff_ignores(ignore_paths):
                 del notebook_differs[path]
         elif isinstance(subkeys, (list, tuple, set)):
             notebook_differs[path] = diff_ignore_keys(notebook_differs[path], subkeys)
+        else:
+            raise ValueError('Invalid ignore config entry: %r: %r' % (path, subkeys))
 
 
 def set_notebook_diff_targets(sources=True, outputs=True, attachments=True,
@@ -567,8 +583,8 @@ def set_notebook_diff_targets(sources=True, outputs=True, attachments=True,
         '/metadata': not metadata,
         '/cells/*/metadata': not metadata,
         '/cells/*/outputs/*/metadata': not metadata,
-        '/cells/*': ('execution_count') if details else False,
-        '/cells/*/outputs/*': ('execution_count') if details else False,
+        '/cells/*': False if details else ('execution_count',),
+        '/cells/*/outputs/*': False if details else ('execution_count',),
     }
     set_notebook_diff_ignores(config)
 
